@@ -6,5 +6,7 @@ Generate changelogs based on tag messages and shortlogs
 """
 
 from .__version__ import __version__
+from .project import Project
+from .tag import Tag
 
 __author__ = "John Reese"
